{{extend defaultLayout}} {{block 'css'}}
<script src="{{_res_path}}template/extend/js/qrcode.min.js"></script>
<link rel="stylesheet" type="text/css" href="{{_res_path}}template/bilibili/css/dynamic/DYNAMIC_TYPE_LIVE_RCMD.css" />
{{/block}} {{block 'main'}}

<div class="spacer1"></div>
{{each image_url val}}
<div class="cover">
  <div class="imgbox">
    <img class="imgbox_1" src="{{val.image_src}}" alt="封面" />
  </div>
</div>
<div style="height: 20px"></div>
{{/each}}
<div class="info">
  <div class="spacer3"></div>
  <div class="info_title" style="font-weight: 700">{{@text}}</div>
  <div class="spacer3"></div>
  <div class="room_id" style="color: #808080; letter-spacing: normal">{{liveinf}}</div>
  <div class="info_text" style="color: #808080; letter-spacing: normal; font-size: 35px;">直播开始时间: {{create_time}}</div>
  <div class="spacer5"></div>
  <div class="avatarinfo">
    <img src="{{avatar_url}}" alt="头像" class="avatar" />
    <img src="{{frame}}" class="avatar-1" />
    <div style "display: flex; flex-direction: column;align-items: flex-start;">
      <div class="name_and_followers">
        <div class="username"><span>{{@username}}</span></div>
        &nbsp;&nbsp;&nbsp;&nbsp;
        <img class="livestat" src="{{_res_path}}image/bilibili/直播中.png" alt="直播中" />
      </div>
      <div>
        <span class="fans">{{fans}}粉丝</span>
      </div>
    </div>
  </div>
  <div class="spacer6"></div>
  <div class="under">
    <div class="other_text">哔哩哔哩{{dynamicTYPE}}</div>
    <div class="rectangular_box">
      <div class="user" style="align-items: center">
        <div class="userinfo">
          <div class="bitop">
            <img src="{{_res_path}}image/bilibili/bilibili-light.png" alt="">
          </div>
          <div class="ftext">
            <span class="t">你感兴趣的视频都在B站</span>
          </div>
        </div>
      </div>
      <div class="qrcode_box">
        <div class="qrcode_text">动态分享链接</div>
        <div id="qrcode"></div>
      </div>
    </div>
  </div>
</div>
<script>
  qrcode = new QRCode(document.getElementById('qrcode'), {
    width: 600,
    height: 600,
    colorDark: '{{useDarkTheme}}' === 'true' ? '#c3c3c3' : '#3a3a3a',
    colorLight: '{{useDarkTheme}}' === 'true' ? '#121212' : '#f4f4f4',
  })
  qrcode.makeCode('{{share_url}}')
</script>
{{/block}}