/** generated by https://github.com/voderl/font-slice */
@font-face {
  font-family: bilifont;
  src: url("./bilifont.1.woff2") format("woff2");
  font-weight: 100;
  font-style: normal;
  font-display: swap;
  unicode-range: U+4e;
}

@font-face {
  font-family: bilifont;
  src: url("./bilifont.2.woff2") format("woff2");
  font-weight: 100;
  font-style: normal;
  font-display: swap;
  unicode-range: U+2e,U+30-39,U+43,U+44,U+4f;
}

@font-face {
  font-family: HarmonyOSHans-Regular;
  src: url("../HarmonyOS_Sans_SC_Regular.woff2") format("woff2");
  font-weight: 100;
  font-style: normal;
  font-display: swap;
}
