body.light-mode .container {
  position: relative;
  background-color: #f4f4f4;
  width: 1440px;
  height: auto;
}

body.dark-mode .container {
  position: relative;
  background-color: #1A1A1A;
  width: 1440px;
  height: auto;
}

.spacer1 {
  height: 60px;
}

.spacer2 {
  height: 82px;
}

.spacer3 {
  height: 50px;
}

.spacer4 {
  height: 60px;
}

.spacer5 {
  height: 10px;
}

.spacer6 {
  height: 100px;
}

.container {
  width: 100% !important;
  margin: 0 auto;
}

body.light-mode .bitop {
  color: #3e3e3eb8;
  font-size: 65px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -moz-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -moz-box-align: center;
  -ms-flex-align: center;
  align-items: center;
  padding: 0 0 0 80px;
}

body.dark-mode .bitop {
  color: #d3d3d3;
  font-size: 65px;
  display: -webkit-box;
  display: -webkit-flex;
  display: -moz-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -moz-box-align: center;
  -ms-flex-align: center;
  align-items: center;
  padding: 0 0 0 50px;
}

.bitop img {
  width: 470px;
  height: auto;
}

.cover {
  display: flex;
  flex-direction: column;
  align-items: center;
}

.imgbox {
  display: flex;
  flex-direction: column;
  align-items: center;
  overflow: hidden;
  box-shadow: 0px 10px 20px 0px #4343434f;
  border-radius: 25px;
  width: 90%;
  flex: 1;
}

.imgbox_1 {
  border-radius: 25px;
  object-fit: contain;
  width: 100%;
  height: 100%;
}

.info {
  width: 100% !important;
  display: flex !important;
  flex-direction: column;
  padding: 0 85px !important;
  line-height: 1.5;
}

body.light-mode .info_text {
  font-size: 50px;
  align-items: center;
  letter-spacing: 1.5px;
  position: relative;
  word-wrap: break-word;
}

body.dark-mode .info_text {
  font-size: 50px;
  align-items: center;
  letter-spacing: 1.5px;
  position: relative;
  word-wrap: break-word;
  color: #e9e9e9;
}

body.light-mode .video_info_text {
  font-size: 80px;
  font-weight: 700;
  align-items: center;
  letter-spacing: 1.5px;
  position: relative;
  word-wrap: break-word;
}

body.dark-mode .video_info_text {
  font-size: 80px;
  font-weight: 700;
  align-items: center;
  letter-spacing: 1.5px;
  position: relative;
  word-wrap: break-word;
  color: #e7e7e7;
}

body.light-mode .intro {
  color: #555555;
  font-size: 60px;
}

body.dark-mode .intro {
  color: #ababab;
  font-size: 60px;
}

.work_status {
  color: #808080;
  letter-spacing: normal;
  font-size: 45px;
  font-weight: 300;
}

.dynamic_create_time {
  white-space: nowrap;
  color: #808080;
  font-size: 35px;
  font-weight: 300;
}

.under {
  display: flex;
  height: 100%;
  flex-direction: column;
}

.rectangular_box {
  height: auto;
  display: -webkit-box;
  display: -webkit-flex;
  display: -moz-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -moz-box-pack: justify;
  -ms-flex-pack: justify;
  justify-content: space-between;
  padding: 100px 0 45px 0;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -moz-box-align: center;
  -ms-flex-align: center;
  align-items: center;
}

.user {
  display: flex;
  flex-direction: column;
  padding-left: 65px;
}

.userinfo {
  display: flex;
  align-items: center;
}

body.light-mode .userinfo_text {
  display: flex;
  font-size: 35px;
  color: #2f2f2fb8;
  padding: 25px 0 0 20px;
  flex-direction: column;
  align-items: flex-start;
  width: 100%;
  letter-spacing: 2.5px;
}

body.dark-mode .userinfo_text {
  display: flex;
  font-size: 35px;
  color: #cfcfcf;
  padding: 25px 0 0 20px;
  flex-direction: column;
  align-items: flex-start;
  width: 100%;
  letter-spacing: 2.5px;
}

.name_and_followers {
  display: flex;
  font-size: 30px;
  flex-direction: column;
}

.name_and_followers_text {
  font-size: 20px;
  color: #2f2f2fb8;
  margin-left: 10px;
  text-align: right;
  margin-right: 10px;
}

.avatar {
  margin: 0px 20px 0 0;
  border-radius: 50%;
  height: auto;
  width: 200px;
  box-shadow: 0px 10px 20px 0px #4343434f;
}

.avatar-1 {
  width: 220px;
  height: 220px;
  margin-right: -160px;
  margin-top: 50px;
  transform: translateY(-13%) translateX(-105%) scale(1.6);
}

/* 当img元素为空时，设置元素透明度为0，图裂图标将被隐藏 */
img[src=''],
img:not([src]) {
  opacity: 0;
}

.username {
  font-weight: 700;
  font-size: 80px;
}

.qrcode_box {
  display: flex !important;
  margin: 0 75px -50px 0 !important;
  align-items: center !important;
  flex-direction: column-reverse;
}

body.light-mode .qrcode_text {
  font-size: 45px;
  color: #2f2f2fb8;
  margin-left: 10px;
  text-align: right;
  margin: 20px 0 0 0;
}

body.dark-mode .qrcode_text {
  font-size: 45px;
  color: #d7d7d7;
  margin-left: 10px;
  text-align: right;
  margin: 20px 0 0 0;
}

body.light-mode #qrcode {
  border: 7px dashed #3a3a3a;
  padding: 10px;
  border-radius: 2%;
}

body.dark-mode #qrcode {
  border: 7px dashed #C3C3C3;
  padding: 10px;
  border-radius: 2%;
}

#qrcode img {
  width: 350px;
  height: auto;
}

body.light-mode .other_text {
  color: #575757;
  font-size: 70px;
  text-align: right;
  margin: 0 80px -45px 0;
  z-index: -1;
}

body.dark-mode .other_text {
  color: #c1c1c1;
  font-size: 70px;
  text-align: right;
  margin: 0 80px -45px 0;
  z-index: -1;
}